==> iReport-0.4.1-src.zip: iReport-0.4.1-src/src/it/businesslogic/ireport/plugin/massivecompiler/ImageCellRenderer.java <==
/*
 * ImageCellRenderer.java
 *
 * Created on 20 maggio 2004, 8.49
 */

package it.businesslogic.ireport.plugin.massivecompiler;

/**
 *
 * @author  Administrator
 */
public class ImageCellRenderer implements javax.swing.table.TableCellRenderer {
    
    javax.swing.Icon icon1 = null;
    javax.swing.Icon icon2 = null;
    javax.swing.Icon icon3 = null;
    
    javax.swing.JLabel label;
    /** Creates a new instance of ImageCellRenderer */
    public ImageCellRenderer() {
        label = new javax.swing.JLabel();
        icon1 = new javax.swing.ImageIcon(getClass().getResource("/it/businesslogic/ireport/icons/tree/docDirty.gif") );
        icon2 = new javax.swing.ImageIcon(getClass().getResource("/it/businesslogic/ireport/icons/tree/doc.gif") );
        icon3 = new javax.swing.ImageIcon(getClass().getResource("/it/businesslogic/ireport/icons/tree/warning.gif") );
        
        label.setIcon( icon1 );
        label.setText("");
    }
    
    public java.awt.Component getTableCellRendererComponent(javax.swing.JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {
    
        if (value instanceof FileEntry)
        {
            if ( ((FileEntry)value).getStatus() == FileEntry.STATUS_COMPILED )
            {
                label.setIcon( icon2 );
            } 
            else if (((FileEntry)value).getStatus() == FileEntry.STATUS_ERROR_COMPILING)
            {
                label.setIcon( icon3 );
            } 
            else if (((FileEntry)value).getStatus() == FileEntry.STATUS_NOT_COMPILED)
            {
                label.setIcon( icon1 );
            }
        }
        else
        {
             label.setIcon( icon1 );
        }
        return label;
    
    }
    
}

==> iReport-1.2.6-src.zip: iReport-1.2.6-src/src/it/businesslogic/ireport/plugin/massivecompiler/ImageCellRenderer.java <==
/*
 * ImageCellRenderer.java
 *
 * Created on 20 maggio 2004, 8.49
 */

package it.businesslogic.ireport.plugin.massivecompiler;

/**
 *
 * @author  Administrator
 */
public class ImageCellRenderer implements javax.swing.table.TableCellRenderer {
    
    javax.swing.Icon icon1 = null;
    javax.swing.Icon icon2 = null;
    javax.swing.Icon icon3 = null;
    
    javax.swing.JLabel label;
    /** Creates a new instance of ImageCellRenderer */
    public ImageCellRenderer() {
        label = new javax.swing.JLabel();
        icon1 = new javax.swing.ImageIcon(getClass().getResource("/it/businesslogic/ireport/icons/tree/docDirty.gif") );
        icon2 = new javax.swing.ImageIcon(getClass().getResource("/it/businesslogic/ireport/icons/tree/doc.gif") );
        icon3 = new javax.swing.ImageIcon(getClass().getResource("/it/businesslogic/ireport/icons/tree/warning.gif") );
        
        label.setIcon( icon1 );
        label.setText("");
    }
    
    public java.awt.Component getTableCellRendererComponent(javax.swing.JTable table, Object value, boolean isSelected, boolean hasFocus, int row, int column) {
    
        if (value instanceof FileEntry)
        {
            if ( ((FileEntry)value).getStatus() == FileEntry.STATUS_COMPILED  || ((FileEntry)value).getStatus() == FileEntry.STATUS_COMPILED_GROOVY)
            {
                label.setIcon( icon2 );
            } 
            else if (((FileEntry)value).getStatus() == FileEntry.STATUS_ERROR_COMPILING)
            {
                label.setIcon( icon3 );
            } 
            else if (((FileEntry)value).getStatus() == FileEntry.STATUS_NOT_COMPILED || ((FileEntry)value).getStatus() == FileEntry.STATUS_COMPILING)
            {
                label.setIcon( icon1 );
            }
        }
        else
        {
             label.setIcon( icon1 );
        }
        return label;
    
    }
    
}
